@@ -29,7 +29,7 @@ func RenderBootstrap(
 	proxyFile,
 	clusterConfigConfigMapFile,
 	infraFile, networkFile,
-	cloudConfigFile,
+	cloudConfigFile, cloudProviderCAFile,
 	etcdCAFile, etcdMetricCAFile, rootCAFile, kubeAPIServerServingCA, pullSecretFile string,
 	imgs *Images,
 	destinationDir string,
@@ -48,6 +48,9 @@ func RenderBootstrap(
 	if kubeAPIServerServingCA != "" {
 		files = append(files, kubeAPIServerServingCA)
 	}
+	if cloudProviderCAFile != "" {
+		files = append(files, cloudProviderCAFile)
+	}
 	for _, file := range files {
 		data, err := ioutil.ReadFile(file)
 		if err != nil {
@@ -129,6 +132,10 @@ func RenderBootstrap(
 		bundle = append(bundle, filesData[kubeAPIServerServingCA]...)
 		spec.KubeAPIServerServingCAData = filesData[kubeAPIServerServingCA]
 	}
+	// Set the cloud-provider CA if given.
+	if data, ok := filesData[cloudProviderCAFile]; ok {
+		spec.CloudProviderCAData = data
+	}
 
 	spec.EtcdCAData = filesData[etcdCAFile]
 	spec.EtcdMetricCAData = filesData[etcdMetricCAFile]
